# these routines calculate various distribution stats from the fitted models

# generic inverse logit function
"invlogit" <- function(x) { exp(x) / (1+exp(x)) }

"dist.pos_means" <- function(pmatrix) {
	# this function takes a player matrix and uses the position
	# designations to calculate the mean values for each position for each model

	# position designations
	positions <- c("PG","SG","SF","PF","C")

	# player data
	lp.o <- as.matrix(read.csv("lp.o.csv",header=F))
	lp.d <- as.matrix(read.csv("lp.d.csv",header=F))
	hp.o <- as.matrix(read.csv("hp.o.csv",header=F))
	hp.d <- as.matrix(read.csv("hp.d.csv",header=F))
	mid.o <- as.matrix(read.csv("mid.o.csv",header=F))
	mid.d <- as.matrix(read.csv("mid.d.csv",header=F))
	corner3.o <- as.matrix(read.csv("corner3.o.csv",header=F))
	corner3.d <- as.matrix(read.csv("corner3.d.csv",header=F))
	other3.o <- as.matrix(read.csv("other3.o.csv",header=F))
	other3.d <- as.matrix(read.csv("other3.d.csv",header=F))

	means <- data.frame(rows=1)

	for (i in 1:NROW(positions)) {
		vals.lp.o <- lp.o[(pmatrix[,3] == positions[i]), 2]
		vals.lp.d <- lp.d[(pmatrix[,3] == positions[i]), 2]
		vals.hp.o <- hp.o[(pmatrix[,3] == positions[i]), 2]
		vals.hp.d <- hp.d[(pmatrix[,3] == positions[i]), 2]
		vals.mid.o <- mid.o[(pmatrix[,3] == positions[i]), 2]
		vals.mid.d <- mid.d[(pmatrix[,3] == positions[i]), 2]
		vals.corner3.o <- corner3.o[(pmatrix[,3] == positions[i]), 2]
		vals.corner3.d <- corner3.d[(pmatrix[,3] == positions[i]), 2]
		vals.other3.o <- other3.o[(pmatrix[,3] == positions[i]), 2]
		vals.other3.d <- other3.d[(pmatrix[,3] == positions[i]), 2]

		if (positions[i] == "PG") {
			means <- data.frame(means, PG.lp.o=mean(as.numeric(vals.lp.o)))
			means <- data.frame(means, PG.hp.o=mean(as.numeric(vals.hp.o)))
			means <- data.frame(means, PG.mid.o=mean(as.numeric(vals.mid.o)))
			means <- data.frame(means, PG.corner3.o=mean(as.numeric(vals.corner3.o)))
			means <- data.frame(means, PG.other3.o=mean(as.numeric(vals.other3.o)))
			means <- data.frame(means, PG.lp.d=mean(as.numeric(vals.lp.d)))
			means <- data.frame(means, PG.hp.d=mean(as.numeric(vals.hp.d)))
			means <- data.frame(means, PG.mid.d=mean(as.numeric(vals.mid.d)))
			means <- data.frame(means, PG.corner3.d=mean(as.numeric(vals.corner3.d)))
			means <- data.frame(means, PG.other3.d=mean(as.numeric(vals.other3.d)))
		} else if (positions[i] == "SG") {
			means <- data.frame(means, SG.lp.o=mean(as.numeric(vals.lp.o)))
			means <- data.frame(means, SG.hp.o=mean(as.numeric(vals.hp.o)))
			means <- data.frame(means, SG.mid.o=mean(as.numeric(vals.mid.o)))
			means <- data.frame(means, SG.corner3.o=mean(as.numeric(vals.corner3.o)))
			means <- data.frame(means, SG.other3.o=mean(as.numeric(vals.other3.o)))
			means <- data.frame(means, SG.lp.d=mean(as.numeric(vals.lp.d)))
			means <- data.frame(means, SG.hp.d=mean(as.numeric(vals.hp.d)))
			means <- data.frame(means, SG.mid.d=mean(as.numeric(vals.mid.d)))
			means <- data.frame(means, SG.corner3.d=mean(as.numeric(vals.corner3.d)))
			means <- data.frame(means, SG.other3.d=mean(as.numeric(vals.other3.d)))
		} else if (positions[i] == "SF") {
			means <- data.frame(means, SF.lp.o=mean(as.numeric(vals.lp.o)))
			means <- data.frame(means, SF.hp.o=mean(as.numeric(vals.hp.o)))
			means <- data.frame(means, SF.mid.o=mean(as.numeric(vals.mid.o)))
			means <- data.frame(means, SF.corner3.o=mean(as.numeric(vals.corner3.o)))
			means <- data.frame(means, SF.other3.o=mean(as.numeric(vals.other3.o)))
			means <- data.frame(means, SF.lp.d=mean(as.numeric(vals.lp.d)))
			means <- data.frame(means, SF.hp.d=mean(as.numeric(vals.hp.d)))
			means <- data.frame(means, SF.mid.d=mean(as.numeric(vals.mid.d)))
			means <- data.frame(means, SF.corner3.d=mean(as.numeric(vals.corner3.d)))
			means <- data.frame(means, SF.other3.d=mean(as.numeric(vals.other3.d)))
		} else if (positions[i] == "PF") {
			means <- data.frame(means, PF.lp.o=mean(as.numeric(vals.lp.o)))
			means <- data.frame(means, PF.hp.o=mean(as.numeric(vals.hp.o)))
			means <- data.frame(means, PF.mid.o=mean(as.numeric(vals.mid.o)))
			means <- data.frame(means, PF.corner3.o=mean(as.numeric(vals.corner3.o)))
			means <- data.frame(means, PF.other3.o=mean(as.numeric(vals.other3.o)))
			means <- data.frame(means, PF.lp.d=mean(as.numeric(vals.lp.d)))
			means <- data.frame(means, PF.hp.d=mean(as.numeric(vals.hp.d)))
			means <- data.frame(means, PF.mid.d=mean(as.numeric(vals.mid.d)))
			means <- data.frame(means, PF.corner3.d=mean(as.numeric(vals.corner3.d)))
			means <- data.frame(means, PF.other3.d=mean(as.numeric(vals.other3.d)))
		} else if (positions[i] == "C") {
			means <- data.frame(means, C.lp.o=mean(as.numeric(vals.lp.o)))
			means <- data.frame(means, C.hp.o=mean(as.numeric(vals.hp.o)))
			means <- data.frame(means, C.mid.o=mean(as.numeric(vals.mid.o)))
			means <- data.frame(means, C.corner3.o=mean(as.numeric(vals.corner3.o)))
			means <- data.frame(means, C.other3.o=mean(as.numeric(vals.other3.o)))
			means <- data.frame(means, C.lp.d=mean(as.numeric(vals.lp.d)))
			means <- data.frame(means, C.hp.d=mean(as.numeric(vals.hp.d)))
			means <- data.frame(means, C.mid.d=mean(as.numeric(vals.mid.d)))
			means <- data.frame(means, C.corner3.d=mean(as.numeric(vals.corner3.d)))
			means <- data.frame(means, C.other3.d=mean(as.numeric(vals.other3.d)))
		}
	}

	return(means)
}

"dist.player_vals" <- function(pmatrix,player) {
	# this function takes a player matrix and player to find model values

	# player data
	lp.o <- as.matrix(read.csv("lp.o.csv",header=F))
	lp.d <- as.matrix(read.csv("lp.d.csv",header=F))
	hp.o <- as.matrix(read.csv("hp.o.csv",header=F))
	hp.d <- as.matrix(read.csv("hp.d.csv",header=F))
	mid.o <- as.matrix(read.csv("mid.o.csv",header=F))
	mid.d <- as.matrix(read.csv("mid.d.csv",header=F))
	corner3.o <- as.matrix(read.csv("corner3.o.csv",header=F))
	corner3.d <- as.matrix(read.csv("corner3.d.csv",header=F))
	other3.o <- as.matrix(read.csv("other3.o.csv",header=F))
	other3.d <- as.matrix(read.csv("other3.d.csv",header=F))

	vals.lp.o <- lp.o[(pmatrix[,2] == player), 2]
	vals.lp.d <- lp.d[(pmatrix[,2] == player), 2]
	vals.hp.o <- hp.o[(pmatrix[,2] == player), 2]
	vals.hp.d <- hp.d[(pmatrix[,2] == player), 2]
	vals.mid.o <- mid.o[(pmatrix[,2] == player), 2]
	vals.mid.d <- mid.d[(pmatrix[,2] == player), 2]
	vals.corner3.o <- corner3.o[(pmatrix[,2] == player), 2]
	vals.corner3.d <- corner3.d[(pmatrix[,2] == player), 2]
	vals.other3.o <- other3.o[(pmatrix[,2] == player), 2]
	vals.other3.d <- other3.d[(pmatrix[,2] == player), 2]

	vals <- data.frame(lp.o=mean(as.numeric(vals.lp.o)))
	vals <- data.frame(vals, hp.o=mean(as.numeric(vals.hp.o)))
	vals <- data.frame(vals, mid.o=mean(as.numeric(vals.mid.o)))
	vals <- data.frame(vals, corner3.o=mean(as.numeric(vals.corner3.o)))
	vals <- data.frame(vals, other3.o=mean(as.numeric(vals.other3.o)))
	vals <- data.frame(vals, lp.d=mean(as.numeric(vals.lp.d)))
	vals <- data.frame(vals, hp.d=mean(as.numeric(vals.hp.d)))
	vals <- data.frame(vals, mid.d=mean(as.numeric(vals.mid.d)))
	vals <- data.frame(vals, corner3.d=mean(as.numeric(vals.corner3.d)))
	vals <- data.frame(vals, other3.d=mean(as.numeric(vals.other3.d)))

	return(vals)
}

"add.proportion" <- function(prop,total) {
	# retuns amount to add (or subtract) from a proportion
	# to make total sum to 1
	extra <- abs(total-1)

	amount <- prop * extra

	if (total > 1) {
		amount <- amount * -1
	}

	return(amount)
}

"dist.tendencies" <- function(player) {
	# this function returns a data frame of player tendencies for each location

	# read in players
	players <- read.csv("players.pos.csv",header=T)
	players.matrix <- as.matrix(players)

	# get position means for each location
	pos_means <- dist.pos_means(players.matrix)

	# read in intercepts
	intercepts <- as.matrix(read.csv("int.csv",header=F))
	#homes <- as.matrix(read.csv("home.csv",header=F))

	# calculate mean proportions
	mean.lp <- invlogit(intercepts[1] + pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o+ pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d)
	mean.hp <- invlogit(intercepts[2] + pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o+ pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d)
	mean.mid <- invlogit(intercepts[3] + pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o+ pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d)
	mean.c3 <- invlogit(intercepts[4] + pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o+ pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d)
	mean.o3 <- invlogit(intercepts[5] + pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o+ pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d)

	# model doesn't give perfect sum to 1, so scale appropriately
	mean.total <- mean.lp+mean.hp+mean.mid+mean.c3+mean.o3
	mean.lp <- mean.lp + add.proportion(mean.lp, mean.total)
	mean.hp <- mean.hp + add.proportion(mean.hp, mean.total)
	mean.mid <- mean.mid + add.proportion(mean.mid, mean.total)
	mean.c3 <- mean.c3 + add.proportion(mean.c3, mean.total)
	mean.o3 <- mean.o3 + add.proportion(mean.o3, mean.total)
	mean.total <- mean.lp+mean.hp+mean.mid+mean.c3+mean.o3

	# find player values now
	player.vals <- dist.player_vals(players.matrix,player)
	player.pos <- players.matrix[(players.matrix[,2] == player),3]

	# calculate offensive values
	off.lp <- 0
	off.hp <- 0
	off.mid <- 0
	off.corner3 <- 0
	off.other3 <- 0

	def.lp <- pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d
	def.hp <- pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d
	def.mid <- pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d
	def.corner3 <- pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d
	def.other3 <- pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d

	if (player.pos == "PG") {
		off.lp <- player.vals$lp.o + pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o
		off.hp <- player.vals$hp.o + pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o
		off.mid <- player.vals$mid.o + pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o
		off.corner3 <- player.vals$corner3.o + pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o
		off.other3 <- player.vals$other3.o + pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o
	} else if (player.pos == "SG") {
		off.lp <- player.vals$lp.o + pos_means$PG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o
		off.hp <- player.vals$hp.o + pos_means$PG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o
		off.mid <- player.vals$mid.o + pos_means$PG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o
		off.corner3 <- player.vals$corner3.o + pos_means$PG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o
		off.other3 <- player.vals$other3.o + pos_means$PG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o
	} else if (player.pos == "SF") {
		off.lp <- player.vals$lp.o + pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o
		off.hp <- player.vals$hp.o + pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o
		off.mid <- player.vals$mid.o + pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o
		off.corner3 <- player.vals$corner3.o + pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o
		off.other3 <- player.vals$other3.o + pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o
	} else if (player.pos == "PF") {
		off.lp <- player.vals$lp.o + pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$C.lp.o
		off.hp <- player.vals$hp.o + pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$C.hp.o
		off.mid <- player.vals$mid.o + pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$C.mid.o
		off.corner3 <- player.vals$corner3.o + pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$C.corner3.o
		off.other3 <- player.vals$other3.o + pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$C.other3.o
	} else if (player.pos == "C") {
		off.lp <- player.vals$lp.o + pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o
		off.hp <- player.vals$hp.o + pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o
		off.mid <- player.vals$mid.o + pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o
		off.corner3 <- player.vals$corner3.o + pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o
		off.other3 <- player.vals$other3.o + pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o
	}

	player.o.lp <- invlogit(intercepts[1] + off.lp + def.lp)
	player.o.hp <- invlogit(intercepts[2] + off.hp + def.hp)
	player.o.mid <- invlogit(intercepts[3] + off.mid + def.mid)
	player.o.c3 <- invlogit(intercepts[4] + off.corner3 + def.corner3)
	player.o.o3 <- invlogit(intercepts[5] + off.other3 + def.other3)

	# model doesn't give perfect sum to 1, so scale appropriately
	player.o.total <- player.o.lp+player.o.hp+player.o.mid+player.o.c3+player.o.o3
	player.o.lp <- player.o.lp + add.proportion(player.o.lp, player.o.total)
	player.o.hp <- player.o.hp + add.proportion(player.o.hp, player.o.total)
	player.o.mid <- player.o.mid + add.proportion(player.o.mid, player.o.total)
	player.o.c3 <- player.o.c3 + add.proportion(player.o.c3, player.o.total)
	player.o.o3 <- player.o.o3 + add.proportion(player.o.o3, player.o.total)
	player.o.total <- player.o.lp+player.o.hp+player.o.mid+player.o.c3+player.o.o3

	# calculate defensive values
	off.lp <- pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o
	off.hp <- pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o
	off.mid <- pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o
	off.corner3 <- pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o
	off.other3 <- pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o

	def.lp <- 0
	def.hp <- 0
	def.mid <- 0
	def.corner3 <- 0
	def.other3 <- 0

	if (player.pos == "PG") {
		def.lp <- player.vals$lp.d + pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d
		def.hp <- player.vals$hp.d + pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d
		def.mid <- player.vals$mid.d + pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d
		def.corner3 <- player.vals$corner3.d + pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d
		def.other3 <- player.vals$other3.d + pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d
	} else if (player.pos == "SG") {
		def.lp <- player.vals$lp.d + pos_means$PG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d
		def.hp <- player.vals$hp.d + pos_means$PG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d
		def.mid <- player.vals$mid.d + pos_means$PG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d
		def.corner3 <- player.vals$corner3.d + pos_means$PG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d
		def.other3 <- player.vals$other3.d + pos_means$PG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d
	} else if (player.pos == "SF") {
		def.lp <- player.vals$lp.d + pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d
		def.hp <- player.vals$hp.d + pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d
		def.mid <- player.vals$mid.d + pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d
		def.corner3 <- player.vals$corner3.d + pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d
		def.other3 <- player.vals$other3.d + pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d
	} else if (player.pos == "PF") {
		def.lp <- player.vals$lp.d + pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$C.lp.d
		def.hp <- player.vals$hp.d + pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$C.hp.d
		def.mid <- player.vals$mid.d + pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$C.mid.d
		def.corner3 <- player.vals$corner3.d + pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$C.corner3.d
		def.other3 <- player.vals$other3.d + pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$C.other3.d
	} else if (player.pos == "C") {
		def.lp <- player.vals$lp.d + pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d
		def.hp <- player.vals$hp.d + pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d
		def.mid <- player.vals$mid.d + pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d
		def.corner3 <- player.vals$corner3.d + pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d
		def.other3 <- player.vals$other3.d + pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d
	}

	player.d.lp <- invlogit(intercepts[1] + off.lp + def.lp)
	player.d.hp <- invlogit(intercepts[2] + off.hp + def.hp)
	player.d.mid <- invlogit(intercepts[3] + off.mid + def.mid)
	player.d.c3 <- invlogit(intercepts[4] + off.corner3 + def.corner3)
	player.d.o3 <- invlogit(intercepts[5] + off.other3 + def.other3)

	# model doesn't give perfect sum to 1, so scale appropriately
	player.d.total <- player.d.lp+player.d.hp+player.d.mid+player.d.c3+player.d.o3
	player.d.lp <- player.d.lp + add.proportion(player.d.lp, player.d.total)
	player.d.hp <- player.d.hp + add.proportion(player.d.hp, player.d.total)
	player.d.mid <- player.d.mid + add.proportion(player.d.mid, player.d.total)
	player.d.c3 <- player.d.c3 + add.proportion(player.d.c3, player.d.total)
	player.d.o3 <- player.d.o3 + add.proportion(player.d.o3, player.d.total)
	player.d.total <- player.d.lp+player.d.hp+player.d.mid+player.d.c3+player.d.o3

#	cat("Mean:\n")
#	cat("LP: ",sprintf("%.3f",mean.lp),"\n",sep="")
#	cat("HP: ",sprintf("%.3f",mean.hp),"\n",sep="")
#	cat("MID: ",sprintf("%.3f",mean.mid),"\n",sep="")
#	cat("C3: ",sprintf("%.3f",mean.c3),"\n",sep="")
#	cat("O3: ",sprintf("%.3f",mean.o3),"\n",sep="")
#	cat("Total: ",sprintf("%.3f",mean.total),"\n",sep="")
#
#	cat("Player Offense:\n")
#	cat("LP: ",sprintf("%.3f",player.o.lp),"\n",sep="")
#	cat("HP: ",sprintf("%.3f",player.o.hp),"\n",sep="")
#	cat("MID: ",sprintf("%.3f",player.o.mid),"\n",sep="")
#	cat("C3: ",sprintf("%.3f",player.o.c3),"\n",sep="")
#	cat("O3: ",sprintf("%.3f",player.o.o3),"\n",sep="")
#	cat("Total: ",sprintf("%.3f",player.o.total),"\n",sep="")
#
#	cat("Player Defense:\n")
#	cat("LP: ",sprintf("%.3f",player.d.lp),"\n",sep="")
#	cat("HP: ",sprintf("%.3f",player.d.hp),"\n",sep="")
#	cat("MID: ",sprintf("%.3f",player.d.mid),"\n",sep="")
#	cat("C3: ",sprintf("%.3f",player.d.c3),"\n",sep="")
#	cat("O3: ",sprintf("%.3f",player.d.o3),"\n",sep="")
#	cat("Total: ",sprintf("%.3f",player.d.total),"\n",sep="")

	t.o.lp <- player.o.lp - mean.lp
	t.o.hp <- player.o.hp - mean.hp
	t.o.mid <- player.o.mid - mean.mid
	t.o.c3 <- player.o.c3 - mean.c3
	t.o.o3 <- player.o.o3 - mean.o3

	t.d.lp <- player.d.lp - mean.lp
	t.d.hp <- player.d.hp - mean.hp
	t.d.mid <- player.d.mid - mean.mid
	t.d.c3 <- player.d.c3 - mean.c3
	t.d.o3 <- player.d.o3 - mean.o3

	t <- data.frame( o.lp=t.o.lp, o.hp=t.o.hp, o.mid=t.o.mid, o.c3=t.o.c3, o.o3=t.o.o3, d.lp=t.d.lp, d.hp=t.d.hp, d.mid=t.d.mid, d.c3=t.d.c3, d.o3=t.d.o3)

	return(t)
}

"dist.get_tendencies" <- function() {
	# this function gets tendencies for each player
	# and prints them. best to sink() this to a file
	players <- read.csv("players.pos.csv",header=T)
	players.matrix <- as.matrix(players)

	for (i in 1:NROW(players.matrix)) {
		t <- dist.tendencies(players.matrix[i,2])
		cat(players.matrix[i,3],",",sep="")
		cat(players.matrix[i,2],",",sep="")
		cat(sprintf("%.1f",t$o.lp*100),",",sep="")
		cat(sprintf("%.1f",t$o.hp*100),",",sep="")
		cat(sprintf("%.1f",t$o.mid*100),",",sep="")
		cat(sprintf("%.1f",t$o.c3*100),",",sep="")
		cat(sprintf("%.1f",t$o.o3*100),",",sep="")
		cat(sprintf("%.1f",t$d.lp*100),",",sep="")
		cat(sprintf("%.1f",t$d.hp*100),",",sep="")
		cat(sprintf("%.1f",t$d.mid*100),",",sep="")
		cat(sprintf("%.1f",t$d.c3*100),",",sep="")
		cat(sprintf("%.1f",t$d.o3*100),"\n",sep="")
	}
}

"dist.combine_players" <- function(PG=NA,SG=NA,SF=NA,PF=NA,C=NA) {
	# this function takes the specified players and combines them
	# to compare them to the leage average offense and defense

	# read in players
	players <- read.csv("players.pos.csv",header=T)
	players.matrix <- as.matrix(players)

	# get position means for each location
	pos_means <- dist.pos_means(players.matrix)

	if (is.na(PG)) {
		# league average PG
		vals.PG <- data.frame(lp.o=pos_means$PG.lp.o, hp.o=pos_means$PG.hp.o, mid.o=pos_means$PG.mid.o, corner3.o=pos_means$PG.corner3.o, other3.o=pos_means$PG.other3.o, lp.d=pos_means$PG.lp.d, hp.d=pos_means$PG.hp.d, mid.d=pos_means$PG.mid.d, corner3.d=pos_means$PG.corner3.d, other3.d=pos_means$PG.other3.d)
	} else {
		# specific PG
		player.pos <- players.matrix[(players.matrix[,2] == PG),3] # get player position (just to make sure)
		if (length(player.pos) == 0) {
			stop("Invalid PG: No such player found")
		} else if (player.pos != "PG") { # not a PG
			warning(paste(PG," listed as a ",player.pos," instead of a PG",sep=""))
		}
		player.vals <- dist.player_vals(players.matrix,PG)
		vals.PG <- data.frame(lp.o=player.vals$lp.o, hp.o=player.vals$hp.o, mid.o=player.vals$mid.o, corner3.o=player.vals$corner3.o, other3.o=player.vals$other3.o, lp.d=player.vals$lp.d, hp.d=player.vals$hp.d, mid.d=player.vals$mid.d, corner3.d=player.vals$corner3.d, other3.d=player.vals$other3.d)
	}

	if (is.na(SG)) {
		# league average SG
		vals.SG <- data.frame(lp.o=pos_means$SG.lp.o, hp.o=pos_means$SG.hp.o, mid.o=pos_means$SG.mid.o, corner3.o=pos_means$SG.corner3.o, other3.o=pos_means$SG.other3.o, lp.d=pos_means$SG.lp.d, hp.d=pos_means$SG.hp.d, mid.d=pos_means$SG.mid.d, corner3.d=pos_means$SG.corner3.d, other3.d=pos_means$SG.other3.d)
	} else {
		# specific SG
		player.pos <- players.matrix[(players.matrix[,2] == SG),3] # get player position (just to make sure)
		if (length(player.pos) == 0) {
			stop("Invalid SG: No such player found")
		} else if (player.pos != "SG") { # not a SG
			warning(paste(SG," listed as a ",player.pos," instead of a SG",sep=""))
		}
		player.vals <- dist.player_vals(players.matrix,SG)
		vals.SG <- data.frame(lp.o=player.vals$lp.o, hp.o=player.vals$hp.o, mid.o=player.vals$mid.o, corner3.o=player.vals$corner3.o, other3.o=player.vals$other3.o, lp.d=player.vals$lp.d, hp.d=player.vals$hp.d, mid.d=player.vals$mid.d, corner3.d=player.vals$corner3.d, other3.d=player.vals$other3.d)
	}

	if (is.na(SF)) {
		# league average SF
		vals.SF <- data.frame(lp.o=pos_means$SF.lp.o, hp.o=pos_means$SF.hp.o, mid.o=pos_means$SF.mid.o, corner3.o=pos_means$SF.corner3.o, other3.o=pos_means$SF.other3.o, lp.d=pos_means$SF.lp.d, hp.d=pos_means$SF.hp.d, mid.d=pos_means$SF.mid.d, corner3.d=pos_means$SF.corner3.d, other3.d=pos_means$SF.other3.d)
	} else {
		# specific SF
		player.pos <- players.matrix[(players.matrix[,2] == SF),3] # get player position (just to make sure)
		if (length(player.pos) == 0) {
			stop("Invalid SF: No such player found")
		} else if (player.pos != "SF") { # not a SF
			warning(paste(SF," listed as a ",player.pos," instead of a SF",sep=""))
		}
		player.vals <- dist.player_vals(players.matrix,SF)
		vals.SF <- data.frame(lp.o=player.vals$lp.o, hp.o=player.vals$hp.o, mid.o=player.vals$mid.o, corner3.o=player.vals$corner3.o, other3.o=player.vals$other3.o, lp.d=player.vals$lp.d, hp.d=player.vals$hp.d, mid.d=player.vals$mid.d, corner3.d=player.vals$corner3.d, other3.d=player.vals$other3.d)
	}

	if (is.na(PF)) {
		# league average PF
		vals.PF <- data.frame(lp.o=pos_means$PF.lp.o, hp.o=pos_means$PF.hp.o, mid.o=pos_means$PF.mid.o, corner3.o=pos_means$PF.corner3.o, other3.o=pos_means$PF.other3.o, lp.d=pos_means$PF.lp.d, hp.d=pos_means$PF.hp.d, mid.d=pos_means$PF.mid.d, corner3.d=pos_means$PF.corner3.d, other3.d=pos_means$PF.other3.d)
	} else {
		# specific PF
		player.pos <- players.matrix[(players.matrix[,2] == PF),3] # get player position (just to make sure)
		if (length(player.pos) == 0) {
			stop("Invalid PF: No such player found")
		} else if (player.pos != "PF") { # not a PF
			warning(paste(PF," listed as a ",player.pos," instead of a PF",sep=""))
		}
		player.vals <- dist.player_vals(players.matrix,PF)
		vals.PF <- data.frame(lp.o=player.vals$lp.o, hp.o=player.vals$hp.o, mid.o=player.vals$mid.o, corner3.o=player.vals$corner3.o, other3.o=player.vals$other3.o, lp.d=player.vals$lp.d, hp.d=player.vals$hp.d, mid.d=player.vals$mid.d, corner3.d=player.vals$corner3.d, other3.d=player.vals$other3.d)
	}

	if (is.na(C)) {
		# league average C
		vals.C <- data.frame(lp.o=pos_means$C.lp.o, hp.o=pos_means$C.hp.o, mid.o=pos_means$C.mid.o, corner3.o=pos_means$C.corner3.o, other3.o=pos_means$C.other3.o, lp.d=pos_means$C.lp.d, hp.d=pos_means$C.hp.d, mid.d=pos_means$C.mid.d, corner3.d=pos_means$C.corner3.d, other3.d=pos_means$C.other3.d)
	} else {
		# specific C
		player.pos <- players.matrix[(players.matrix[,2] == C),3] # get player position (just to make sure)
		if (length(player.pos) == 0) {
			stop("Invalid C: No such player found")
		} else if (player.pos != "C") { # not a C
			warning(paste(C," listed as a ",player.pos," instead of a C",sep=""))
		}
		player.vals <- dist.player_vals(players.matrix,C)
		vals.C <- data.frame(lp.o=player.vals$lp.o, hp.o=player.vals$hp.o, mid.o=player.vals$mid.o, corner3.o=player.vals$corner3.o, other3.o=player.vals$other3.o, lp.d=player.vals$lp.d, hp.d=player.vals$hp.d, mid.d=player.vals$mid.d, corner3.d=player.vals$corner3.d, other3.d=player.vals$other3.d)
	}

	# read in intercepts
	intercepts <- as.matrix(read.csv("int.csv",header=F))
	#homes <- as.matrix(read.csv("home.csv",header=F))

	# offensive distribution
	off.lp <- invlogit(intercepts[1]
		+ vals.PG$lp.o+vals.SG$lp.o+vals.SF$lp.o+vals.PF$lp.o+vals.C$lp.o
		+ pos_means$PG.lp.d+pos_means$SG.lp.d+pos_means$SF.lp.d+pos_means$PF.lp.d+pos_means$C.lp.d)
	off.hp <- invlogit(intercepts[2]
		+ vals.PG$hp.o+vals.SG$hp.o+vals.SF$hp.o+vals.PF$hp.o+vals.C$hp.o
		+ pos_means$PG.hp.d+pos_means$SG.hp.d+pos_means$SF.hp.d+pos_means$PF.hp.d+pos_means$C.hp.d)
	off.mid <- invlogit(intercepts[3]
		+ vals.PG$mid.o+vals.SG$mid.o+vals.SF$mid.o+vals.PF$mid.o+vals.C$mid.o
		+ pos_means$PG.mid.d+pos_means$SG.mid.d+pos_means$SF.mid.d+pos_means$PF.mid.d+pos_means$C.mid.d)
	off.corner3 <- invlogit(intercepts[4]
		+ vals.PG$corner3.o+vals.SG$corner3.o+vals.SF$corner3.o+vals.PF$corner3.o+vals.C$corner3.o
		+ pos_means$PG.corner3.d+pos_means$SG.corner3.d+pos_means$SF.corner3.d+pos_means$PF.corner3.d+pos_means$C.corner3.d)
	off.other3 <- invlogit(intercepts[5]
		+ vals.PG$other3.o+vals.SG$other3.o+vals.SF$other3.o+vals.PF$other3.o+vals.C$other3.o
		+ pos_means$PG.other3.d+pos_means$SG.other3.d+pos_means$SF.other3.d+pos_means$PF.other3.d+pos_means$C.other3.d)

	# model doesn't give perfect sum to 1, so scale appropriately
	off.total <- off.lp+off.hp+off.mid+off.corner3+off.other3
	off.lp <- off.lp + add.proportion(off.lp, off.total)
	off.hp <- off.hp + add.proportion(off.hp, off.total)
	off.mid <- off.mid + add.proportion(off.mid, off.total)
	off.corner3 <- off.corner3 + add.proportion(off.corner3, off.total)
	off.other3 <- off.other3 + add.proportion(off.other3, off.total)
	off.total <- off.lp+off.hp+off.mid+off.corner3+off.other3

	# defensive distribution
	def.lp <- invlogit(intercepts[1]
		+ vals.PG$lp.d+vals.SG$lp.d+vals.SF$lp.d+vals.PF$lp.d+vals.C$lp.d
		+ pos_means$PG.lp.o+pos_means$SG.lp.o+pos_means$SF.lp.o+pos_means$PF.lp.o+pos_means$C.lp.o)
	def.hp <- invlogit(intercepts[2]
		+ vals.PG$hp.d+vals.SG$hp.d+vals.SF$hp.d+vals.PF$hp.d+vals.C$hp.d
		+ pos_means$PG.hp.o+pos_means$SG.hp.o+pos_means$SF.hp.o+pos_means$PF.hp.o+pos_means$C.hp.o)
	def.mid <- invlogit(intercepts[3]
		+ vals.PG$mid.d+vals.SG$mid.d+vals.SF$mid.d+vals.PF$mid.d+vals.C$mid.d
		+ pos_means$PG.mid.o+pos_means$SG.mid.o+pos_means$SF.mid.o+pos_means$PF.mid.o+pos_means$C.mid.o)
	def.corner3 <- invlogit(intercepts[4]
		+ vals.PG$corner3.d+vals.SG$corner3.d+vals.SF$corner3.d+vals.PF$corner3.d+vals.C$corner3.d
		+ pos_means$PG.corner3.o+pos_means$SG.corner3.o+pos_means$SF.corner3.o+pos_means$PF.corner3.o+pos_means$C.corner3.o)
	def.other3 <- invlogit(intercepts[5]
		+ vals.PG$other3.d+vals.SG$other3.d+vals.SF$other3.d+vals.PF$other3.d+vals.C$other3.d
		+ pos_means$PG.other3.o+pos_means$SG.other3.o+pos_means$SF.other3.o+pos_means$PF.other3.o+pos_means$C.other3.o)

	# model doesn't give perfect sum to 1, so scale appropriately
	def.total <- def.lp+def.hp+def.mid+def.corner3+def.other3
	def.lp <- def.lp + add.proportion(def.lp, def.total)
	def.hp <- def.hp + add.proportion(def.hp, def.total)
	def.mid <- def.mid + add.proportion(def.mid, def.total)
	def.corner3 <- def.corner3 + add.proportion(def.corner3, def.total)
	def.other3 <- def.other3 + add.proportion(def.other3, def.total)
	def.total <- def.lp+def.hp+def.mid+def.corner3+def.other3

	cat("Offense:\n")
	cat("--> LP: ", sprintf("%.1f", off.lp*100), "%\n",sep="")
	cat("--> HP: ", sprintf("%.1f", off.hp*100), "%\n",sep="")
	cat("--> MID: ", sprintf("%.1f", off.mid*100), "%\n",sep="")
	cat("--> C3: ", sprintf("%.1f", off.corner3*100), "%\n",sep="")
	cat("--> O3: ", sprintf("%.1f", off.other3*100), "%\n",sep="")
	#cat("--> Sum: ", sprintf("%.1f", (off.lp+off.hp+off.mid+off.corner3+off.other3)*100), "%\n",sep="")

	cat("Defense:\n")
	cat("--> LP: ", sprintf("%.1f", def.lp*100), "%\n",sep="")
	cat("--> HP: ", sprintf("%.1f", def.hp*100), "%\n",sep="")
	cat("--> MID: ", sprintf("%.1f", def.mid*100), "%\n",sep="")
	cat("--> C3: ", sprintf("%.1f", def.corner3*100), "%\n",sep="")
	cat("--> O3: ", sprintf("%.1f", def.other3*100), "%\n",sep="")
	#cat("--> Sum: ", sprintf("%.1f", (def.lp+def.hp+def.mid+def.corner3+def.other3)*100), "%\n",sep="")

	#cat(vals.PG$lp.o,"\n") cat(vals.SG$lp.o,"\n") cat(vals.SF$lp.o,"\n") cat(vals.PF$lp.o,"\n") cat(vals.C$lp.o,"\n")
	#cat(vals.PG$lp.d,"\n") cat(vals.SG$lp.d,"\n") cat(vals.SF$lp.d,"\n") cat(vals.PF$lp.d,"\n") cat(vals.C$lp.d,"\n")
}
